==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/nl/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Stel in als standaard module',
    '<strong>Module</strong> details' => '<strong>Module</strong> details',
    'Activated' => 'Ingeschakeld',
    'Always activated' => 'Altijd geactiveerd',
    'Are you sure? *ALL* module data will be lost!' => 'Weet u het zeker? *ALLE* module gegevens zal verloren gaan!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Weet u het zeker? *ALLE* gegevens en bestanden gerelateerd aan de module zullen verloren gaan!',
    'Close' => 'Sluiten',
    'Configure' => 'Configureren',
    'Could not find requested module!' => 'Kon de gevraagde module niet vinden!',
    'Deactivated' => 'Gedeactiveerd',
    'Enable module...' => 'Module inschakelen...',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Hier kunt u kiezen of een module automatisch geactiveerd moet worden voor een ruimte of gebruikersprofiel. Als de module moet worden geactiveerd, kies dan "altijd geactiveerd".',
    'License not found or expired. Please contact the module publisher.' => 'Licentie niet gevonden of is verlopen. Neem contact op met de module-maker.',
    'Module path %path% is not writeable!' => 'Module pad %path% is niet schrijfbaar',
    'Save' => 'Bewaar',
    'Spaces' => 'Ruimtes',
    'This module doesn\'t provide further information.' => 'Deze module heeft geen verdere informatie.',
    'Activate' => '',
    'Deprecated' => '',
    'Featured' => '',
    'Installed' => '',
    'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
    'New' => '',
    'No modules found.' => '',
    'Not Installed' => '',
    'Official' => '',
    'Partner' => '',
    'Professional Edition' => '',
    'Space default state' => '',
    'Try other keywords or remove filters.' => '',
    'Update successful' => '',
    'User default state' => '',
    'Users' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/nl/modules.php <==
<?php

return [
    '%moduleName% - Set as default module' => '%moduleName% - Stel in als standaard module',
    'Activated' => 'Ingeschakeld',
    'Always activated' => 'Altijd geactiveerd',
    'Are you sure? *ALL* module data will be lost!' => 'Weet u het zeker? *ALLE* module gegevens zal verloren gaan!',
    'Are you sure? *ALL* module related data and files will be lost!' => 'Weet u het zeker? *ALLE* gegevens en bestanden gerelateerd aan de module zullen verloren gaan!',
    'Close' => 'Sluiten',
    'Could not find requested module!' => 'Kon de gevraagde module niet vinden!',
    'Deactivated' => 'Gedeactiveerd',
    'Deactivation of this module has not been completed yet. Please retry in a few minutes.' => 'Het deactiveren van deze module is nog niet voltooid. Probeer het over een paar minuten opnieuw.',
    'Enable module...' => 'Module inschakelen...',
    'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Hier kunt u kiezen of een module automatisch geactiveerd moet worden voor een ruimte of gebruikersprofiel. Als de module moet worden geactiveerd, kies dan "altijd geactiveerd".',
    'Module path %path% is not writeable!' => 'Module pad %path% is niet beschrijfbaar',
    'Save' => 'Bewaar',
    'Space default state' => 'Standaard ruimtestatus',
    'Spaces' => 'Ruimtes',
    'User default state' => 'Standaard gebruikersstatus:',
    'Users' => 'Gebruikers',
    'Module deactivation in progress. This process may take a moment.' => '',
];
